==> igniteui-react-charts-16.4.1.tgz: package/ES2015/AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES2015/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES2015/Color";
export class AreaSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.p8 = null;
        this.p8 = new CategoryLineRasterizer();
        this.ab = AreaSeries.$;
        this.pr = 0;
    }
    bf() {
        return new AreaSeriesView(this);
    }
    m7() {
        return 1;
    }
    il(a) {
        super.il(a);
        this.p7 = a;
    }
    get_ck() {
        return true;
    }
    get ck() {
        return this.get_ck();
    }
    preferredCategoryMode(a) {
        return this.pr;
    }
    df(a, b) {
        let c = this.lc(this.lf(a), true, false);
        if (this.py(a, c, b)) {
            return true;
        }
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c5();
    }
    oe(a, b) {
        super.oe(a, b);
        let c = b.cl.d;
        let d = typeCast(AreaSeriesView.$, b);
        let e = a.f;
        let f = this.getEffectiveViewport1(d);
        this.m5.x(this, this.nq(), this.po, runOn(this, this.mr), this.ny(b), this.nz(b));
        let g = false;
        let h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            let i = new ScalerParams(0, b.bq, b.bp, this.po.b8, f);
            this.oa(e, -1, this.valueColumn.count, this.po, i, b.n);
        }
        let j = d.dc;
        let k = d.dd;
        let l = d.df;
        let m = d.dh;
        this.m5.ae(j, true, false, true, true);
        this.m5.ae(k, true, false, true, true);
        this.m5.ae(l, false, true, false, false);
        this.m5.ae(m, false, true, false, false);
        if (b.cp(a)) {
            d.c7(e.count, e, true, c, this.eq, (n, o, p, q, r) => this.o8(n, a.f.count, b), this.unknownValuePlotting, e.count == 1 ? null : this.on(e, e.count - 1, b.bp, b.bq, true));
            b.cs(a);
        }
        let n = this.fetchYAxis();
        l._opacity = this.m5.i * this.d2;
        m._opacity = 0.5 * this.m5.i * this.d2;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case AreaSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
AreaSeries.$t = markType(AreaSeries, 'AreaSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
Type.dep(DependencyProperty, PropertyMetadata, AreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qa', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
export class AreaSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c4 = null;
        this.de = new Path();
        this.di = new Path();
        this.dg = new Path();
        this.dj = new Path();
        this.c8 = new Path();
        this.da = new Path();
        this.c9 = new Path();
        this.db = new Path();
        this.c4 = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get dc() {
        return this.di;
    }
    get dd() {
        return this.dj;
    }
    get df() {
        return this.de;
    }
    get dh() {
        return this.dg;
    }
    c5() {
        this.de.aj = null;
        this.dg.aj = null;
        this.di.aj = null;
        this.dj.aj = null;
        this.an();
    }
    c6(a, b, c, d, e, f, g) {
        this.c7(a, b, c, d, e, f, g, null);
    }
    c7(a, b, c, d, e, f, g, h) {
        this.c4.p8.a = typeCast(ISortingAxis_$type, this.cn.fetchXAxis()) !== null ? true : false;
        this.c4.p8.j(this.de, this.di, this.dg, this.dj, a, b, c, d, e, f, g, h);
        this.an();
    }
    a9() {
        super.a9();
        this.c8.aj = this.de.aj;
        this.da.aj = this.di.aj;
        this.c9.aj = this.dg.aj;
        this.db.aj = this.dj.aj;
        let a = this.bk();
        this.c8._fill = a;
        this.c8._opacity = 1;
        this.c9._fill = a;
        this.c9._opacity = 1;
        this.da._stroke = a;
        this.da.ac = this.e.eu + 3;
        this.db._stroke = a;
        this.db.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (b) {
            a.s(this.c8);
            a.s(this.c9);
            a.s(this.da);
            a.s(this.db);
        }
        else {
            a.s(this.de);
            a.s(this.dg);
            a.s(this.di);
            a.s(this.dj);
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.di, "lowerShape", ["Lower"]);
        this.e.a2.exportPathData(a, this.dj, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPathData(a, this.dg, "translucentShape", ["Translucent"]);
        this.e.a2.exportPathData(a, this.de, "fillShape", ["Fill"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 1;
        this.e.et = -3;
    }
}
AreaSeriesView.$t = markType(AreaSeriesView, 'AreaSeriesView', AnchoredCategorySeriesView.$);
/*<BeginStatics Name="Infragistics.Controls.Charts.AreaSeries" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.AreaSeries" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES2015/AreaSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { IUnknownValuePlotting_$type } from "igniteui-react-core/ES2015/IUnknownValuePlotting";
import { CategoryLineRasterizer } from "./CategoryLineRasterizer";
import { UnknownValuePlotting_$type } from "igniteui-react-core/ES2015/UnknownValuePlotting";
import { DependencyProperty } from "igniteui-react-core/ES2015/DependencyProperty";
import { Type, typeCast, runOn, enumGetBox, markType } from "igniteui-react-core/ES2015/type";
import { Path } from "igniteui-react-core/ES2015/Path";
import { ScalerParams } from "./ScalerParams";
import { PropertyMetadata } from "igniteui-react-core/ES2015/PropertyMetadata";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { ISortingAxis_$type } from "./ISortingAxis";
import { Color } from "igniteui-react-core/ES2015/Color";
export class AreaSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.p9 = null;
        this.p9 = new CategoryLineRasterizer();
        this.ab = AreaSeries.$;
        this.ps = 0;
    }
    bf() {
        return new AreaSeriesView(this);
    }
    m7() {
        return 1;
    }
    il(a) {
        super.il(a);
        this.p8 = a;
    }
    get_ck() {
        return true;
    }
    preferredCategoryMode(a) {
        return this.ps;
    }
    df(a, b) {
        let c = this.lc(this.lf(a), true, false);
        if (this.pz(a, c, b)) {
            return true;
        }
        if (this.de(a, b)) {
            return true;
        }
        if (this.lv(a, b)) {
            return true;
        }
        return false;
    }
    ho(a, b) {
        super.ho(a, b);
        let c = b;
        c.c7();
    }
    of(a, b) {
        super.of(a, b);
        let c = b.cn.d;
        let d = typeCast(AreaSeriesView.$, b);
        let e = a.f;
        let f = this.getEffectiveViewport1(d);
        this.m5.x(this, this.nq(), this.pp, runOn(this, this.mr), this.ny(b), this.nz(b));
        let g = false;
        let h = this.m5.c;
        if (h != null) {
            g = true;
        }
        if (g) {
            let i = new ScalerParams(0, b.bs, b.br, this.pp.b8, f);
            this.ob(e, -1, this.valueColumn.count, this.pp, i, b.n);
        }
        let j = d.de;
        let k = d.df;
        let l = d.dh;
        let m = d.dj;
        this.m5.ae(j, true, false, true, true);
        this.m5.ae(k, true, false, true, true);
        this.m5.ae(l, false, true, false, false);
        this.m5.ae(m, false, true, false, false);
        if (b.cr(a)) {
            d.c9(e.count, e, true, c, this.eq, (n, o, p, q, r) => this.o9(n, a.f.count, b), this.unknownValuePlotting, e.count == 1 ? null : this.oo(e, e.count - 1, b.br, b.bs, true));
            b.cu(a);
        }
        let n = this.fetchYAxis();
        l._opacity = this.m5.i * this.d2;
        m._opacity = 0.5 * this.m5.i * this.d2;
    }
    ir(a, b, c, d) {
        super.ir(a, b, c, d);
        switch (b) {
            case AreaSeries.$$p[0]:
                this.m2.m = this.unknownValuePlotting == 0;
                this.i4(false);
                this.ib();
                break;
        }
    }
    get useHighMarkerFidelity() {
        return this.nt;
    }
}
AreaSeries.$t = markType(AreaSeries, 'AreaSeries', HorizontalAnchoredCategorySeries.$, [IUnknownValuePlotting_$type]);
Type.dep(DependencyProperty, PropertyMetadata, AreaSeries, 'raisePropertyChanged', ['UnknownValuePlotting::qb', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
export class AreaSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.dg = new Path();
        this.dk = new Path();
        this.di = new Path();
        this.dl = new Path();
        this.da = new Path();
        this.dc = new Path();
        this.db = new Path();
        this.dd = new Path();
        this.c6 = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.e.bj = 1;
        }
    }
    get de() {
        return this.dk;
    }
    get df() {
        return this.dl;
    }
    get dh() {
        return this.dg;
    }
    get dj() {
        return this.di;
    }
    c7() {
        this.dg.aj = null;
        this.di.aj = null;
        this.dk.aj = null;
        this.dl.aj = null;
        this.an();
    }
    c8(a, b, c, d, e, f, g) {
        this.c9(a, b, c, d, e, f, g, null);
    }
    c9(a, b, c, d, e, f, g, h) {
        this.c6.p9.a = typeCast(ISortingAxis_$type, this.cp.fetchXAxis()) !== null ? true : false;
        this.c6.p9.j(this.dg, this.dk, this.di, this.dl, a, b, c, d, e, f, g, h);
        this.an();
    }
    a9() {
        super.a9();
        this.da.aj = this.dg.aj;
        this.dc.aj = this.dk.aj;
        this.db.aj = this.di.aj;
        this.dd.aj = this.dl.aj;
        let a = this.bl();
        this.da._fill = a;
        this.da._opacity = 1;
        this.db._fill = a;
        this.db._opacity = 1;
        this.dc._stroke = a;
        this.dc.ac = this.e.eu + 3;
        this.dd._stroke = a;
        this.dd.ac = this.e.eu + 3;
    }
    a3(a, b) {
        super.a3(a, b);
        if (b) {
            a.s(this.da);
            a.s(this.db);
            a.s(this.dc);
            a.s(this.dd);
        }
        else {
            a.s(this.dg);
            a.s(this.di);
            a.s(this.dk);
            a.s(this.dl);
        }
    }
    ai(a) {
        super.ai(a);
        this.e.a2.exportPathData(a, this.dk, "lowerShape", ["Lower"]);
        this.e.a2.exportPathData(a, this.dl, "upperShape", ["Upper", "Main"]);
        this.e.a2.exportPathData(a, this.di, "translucentShape", ["Translucent"]);
        this.e.a2.exportPathData(a, this.dg, "fillShape", ["Fill"]);
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k1 = a;
        this.e.er = 5;
        this.e.es = 1;
        this.e.et = -3;
    }
}
AreaSeriesView.$t = markType(AreaSeriesView, 'AreaSeriesView', AnchoredCategorySeriesView.$);
